summaryrefslogtreecommitdiffstats
path: root/libkcal/tests/testfields.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'libkcal/tests/testfields.cpp')
-rw-r--r--libkcal/tests/testfields.cpp18
1 files changed, 9 insertions, 9 deletions
diff --git a/libkcal/tests/testfields.cpp b/libkcal/tests/testfields.cpp
index a6117088..bb95d1f3 100644
--- a/libkcal/tests/testfields.cpp
+++ b/libkcal/tests/testfields.cpp
@@ -58,8 +58,8 @@ int main(int argc,char **argv)
return 1;
}
// 2 tests... first uid should result in a syncStatus of 0. second uid
// should have a new summary and a 1 for syncStatus.
TQString uid1 = TQString::tqfromLatin1("KOrganizer-1345486115.965");
TQString uid2 = TQString::tqfromLatin1("KOrganizer-1345486115.967");
@@ -78,7 +78,7 @@ int main(int argc,char **argv)
if (e->pilotId()) {
kdDebug() << "Pilot ID = " << e->pilotId() << endl;
- kdDebug() << "Pilot Sync Status = " << e->syncStatus() << endl;
+ kdDebug() << "Pilot Sync tqStatus = " << e->synctqStatus() << endl;
} else {
kdError() << "No Pilot ID" << endl;
return 1;
@@ -86,7 +86,7 @@ int main(int argc,char **argv)
kdDebug() << "First test passed. Able to read fields." << endl;
- e->setSyncStatus(KCal::Incidence::SYNCNONE);
+ e->setSynctqStatus(KCal::Incidence::SYNCNONE);
TQString newSummary = TQString::tqfromLatin1("Mooo summary");
@@ -120,7 +120,7 @@ int main(int argc,char **argv)
TQFile::remove( filew );
// check for uid1--should have syncStatus of 0
e = cal2.event( uid1 );
if (!e) {
kdError() << "No event for first read test" << uid1 << endl;
@@ -131,13 +131,13 @@ int main(int argc,char **argv)
if (e->pilotId()) {
kdDebug() << "First Pilot ID = " << e->pilotId() << endl;
- kdDebug() << "First Pilot Sync Status = " << e->syncStatus() << endl;
+ kdDebug() << "First Pilot Sync tqStatus = " << e->synctqStatus() << endl;
} else {
kdError() << "No Pilot ID for first test" << endl;
return 1;
}
- if (e->syncStatus() != KCal::Incidence::SYNCNONE) {
+ if (e->synctqStatus() != KCal::Incidence::SYNCNONE) {
kdError() << "Wrong Pilot sync status." << endl;
return 1;
}
@@ -154,13 +154,13 @@ int main(int argc,char **argv)
if (f->pilotId()) {
kdDebug() << "Second Pilot ID = " << f->pilotId() << endl;
- kdDebug() << "Second Pilot Sync Status = " << f->syncStatus() << endl;
+ kdDebug() << "Second Pilot Sync tqStatus = " << f->synctqStatus() << endl;
} else {
kdError() << "No Pilot ID for second read test" << endl;
return 1;
}
- if (f->syncStatus() != KCal::Incidence::SYNCMOD) {
+ if (f->synctqStatus() != KCal::Incidence::SYNCMOD) {
kdError() << "Wrong Pilot sync status for second read test." << endl;
return 1;
}
@@ -58,8 +58,8 @@ int main(int argc,char **argv)
return 1;
}
- // 2 tests... first uid should result in a syncStatus of 0. second uid
- // should have a new summary and a 1 for syncStatus.
+ // 2 tests... first uid should result in a synctqStatus of 0. second uid
+ // should have a new summary and a 1 for synctqStatus.
TQString uid1 = TQString::tqfromLatin1("KOrganizer-1345486115.965");
TQString uid2 = TQString::tqfromLatin1("KOrganizer-1345486115.967");
@@ -120,7 +120,7 @@ int main(int argc,char **argv)
TQFile::remove( filew );
- // check for uid1--should have syncStatus of 0
+ // check for uid1--should have synctqStatus of 0
e = cal2.event( uid1 );
if (!e) {